﻿//
// Myriadbits Disk space analyzer 
// Find free space on your NTFS disk
// Copyright (C) 2014 Myriadbits, Jochem Bakker
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// For more information, contact me at: info@myriadbits.com
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;

namespace Myriadbits.DiskSpaceAnalyzer
{
	public partial class ProgressForm : Form
	{
		private Stopwatch sw = new Stopwatch();

		public ProgressForm()
		{
			InitializeComponent();
		}

		public void Start(Form owner)
		{
			this.txtCurrent.Text = "";
			this.txtMaximum.Text = "";
			this.txtTime.Text = "0";
			this.txtETA.Text = "";
			this.sw.Restart();
			this.Show(owner);

			this.StartPosition = FormStartPosition.Manual;
			this.Location = new Point(owner.Location.X + (owner.Width - this.Width) / 2, owner.Location.Y + (owner.Height - this.Height) / 2);
		}

		public void SetProgress(ulong current, ulong maximum)
		{
			this.mainProgress.Maximum = (int)maximum;
			this.mainProgress.Value = (int)current;

			this.txtCurrent.Text = string.Format("{0:### ### ### ### ### ###}", current);
			this.txtMaximum.Text = string.Format("{0:### ### ### ### ### ###}", maximum);
			this.txtTime.Text = string.Format("{0:0} s", this.sw.Elapsed.TotalSeconds);
			if (this.sw.ElapsedMilliseconds != 0 && current > 0)
			{
				double speed = ((double) current) / this.sw.ElapsedMilliseconds;
				double eta = (maximum - current) / speed;
				this.txtETA.Text = string.Format("{0:0} s", (eta / 1000));
			}
			else
				this.txtETA.Text = "";
		}

	}
}
